Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateJWT ¶
GenerateJWT generates a JWT token with a given expiration or defaults to 24 hours
func GenerteJWTSecret ¶
GenerteJWTSecret generates a secure random secret key and sets it as an environment variable.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.